@@ -4,7 +4,7 @@ TODO:
 """
 
 from .imports import *
-from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer, _eksamener, _studieretning, _spørgeskema
+from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer, _eksamener, _studieretning, _spørgeskema, _termin
 
 class sdk:
     def __init__(self, brugernavn, adgangskode, skoleId, base64Cookie=None):
@@ -94,4 +94,19 @@ class sdk:
         return _dokumenter.opretMappe(self, folderName, folderComment, folderId)
 
     def holdTilFag(self, holdId):
-        return _skema.holdTilFag(self, holdId)
\ No newline at end of file
+        return _skema.holdTilFag(self, holdId)
+
+    def fåTerminer(self):
+        return _termin.fåTerminer(self)
+
+    def ændreTermin(self, terminId):
+        return _termin.ændreTermin(self, terminId)
+
+    def spørgeskema(self, id):
+        return _spørgeskema.spørgeskema(self, id)
+
+    def besvarSpørgeskema(self, id, besvarelser):
+        return _spørgeskema.besvarSpørgeskema(self, id, besvarelser)
+
+    def lokaleDagsorden(self):
+        return _ledigeLokaler.lokaleDagsorden(self)
\ No newline at end of file
